/*
 *  GuiLoader/C++ examples
 *  Copyright (c) 2006-2010 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifdef _WIN32
	#include <gdk/gdkwin32.h>
#endif

#include <glib/gi18n.h>
#include <guiloader-c++.h> 

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

namespace GuiExample {

class Application : public sigc::trackable {

public:
	Application() {
		loader= Gui::Loader::create();

		GUIXML_DECL
			#include "hello.gui.h"
		GUIXML_LOAD_CPP(loader)

		loader->bind_object("window1", &window);
	}
	
	Gtk::Window * getWindow() { return window; }

private:
	Gui::PLoader loader;
	Gtk::Window * window;

};

int Main(int argc, char ** argv) {
	Gtk::Main gtkmain(&argc, &argv);
	Gui::Enter enter;

	#if ENABLE_NLS
		bindtextdomain(PACKAGE, LOCALEDIR);
		bind_textdomain_codeset(PACKAGE, "UTF-8");
		textdomain(PACKAGE);
	#endif

	Application application;
	Gtk::Main::run(*application.getWindow());
	return 0;
}

}

#ifdef _WIN32
	int WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
		{ return GuiExample::Main(__argc, __argv); }
#else
	int main(int argc, char ** argv) 
		{ return GuiExample::Main(argc, argv); }
#endif
