/*
 *  GuiLoader/C++ examples
 *  Copyright (c) 2006-2010 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifdef _WIN32
	#include <gdk/gdkwin32.h>
#endif

#include <guiloader-c++.h> 

namespace GuiExample {

class Application : public sigc::trackable {

public:
	Application() {
		loader= Gui::Loader::create();

		GUIXML_DECL
			#include "simple.gui.h"
		GUIXML_LOAD_CPP(loader)

		loader->bind_object("window1", &window);
		loader->bind_object("button1", &button);
		
		loader->connect_signals("onDeleteEvent", sigc::mem_fun(*this, &Application::onDeleteEvent));
		loader->connect_signals("onButtonClicked", sigc::mem_fun(*this, &Application::onButtonClicked));
		loader->connect_signals_s("onCheckToggled", sigc::mem_fun(*this, &Application::onCheckToggled));
	}
	
	Gtk::Window * getWindow() { return window; }

protected:
	bool onDeleteEvent(GdkEventAny *) { return true; }
	void onButtonClicked() { window->hide(); }
	
	void onCheckToggled(Glib::Object * source) { 
		Gtk::CheckButton * check= dynamic_cast<Gtk::CheckButton *>(source);
		button->set_sensitive(check->get_active()); 
	}
	
private:
	Gui::PLoader loader;
	Gtk::Window * window;
	Gtk::Button * button;

};

int Main(int argc, char ** argv) {
	Gtk::Main gtkmain(&argc, &argv);
	Gui::Enter enter;
	Application application;
	Gtk::Main::run(*application.getWindow());
	return 0;
}

}

#ifdef _WIN32
	int WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
		{ return GuiExample::Main(__argc, __argv); }
#else
	int main(int argc, char ** argv) 
		{ return GuiExample::Main(argc, argv); }
#endif
