/*
 *  GuiLoader/C++ examples
 *  Copyright (c) 2006-2010 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifndef EXAMPLE_APPLICATION_H
#define EXAMPLE_APPLICATION_H

#ifdef _WIN32
	#include <gdk/gdkwin32.h>
#endif

#include <guiloader-c++.h>

#include <iostream>
#include <sstream>

namespace GuiExample {

class Application : public sigc::trackable {

public:
	Application();
	~Application();

	Gtk::Window * getWindow() { return window; }

protected:
	void updateUi();
	void setText(const Glib::ustring & text);
	
	void onChanged();
	void onMarkSet(const Gtk::TextBuffer::iterator &, const Glib::RefPtr<Gtk::TextBuffer::Mark> &);
	void onNew();
	void onOpen();
	void onSave();
	void onSaveAs();
	void onQuit();
	void onCut();
	void onCopy();
	void onPaste();
	void onDelete();
	void onAbout();
	bool onDeleteEvent(GdkEventAny *);

	bool loadFile(const std::string & name, Glib::ustring * data);
	bool saveFile(const std::string & name, const Glib::ustring & data);
	std::string askFilename(Gtk::FileChooserAction action);
	bool askProceed();

	void showMessage(const Glib::ustring & message);

private:
	Gui::PLoader loader;

	std::string file;
	bool modified;
	bool lock;

	Gtk::Window * window;
	Glib::RefPtr<Gtk::ActionGroup> actions;
	Gtk::TextView * textView;
	Gtk::Statusbar * statusbar;

	Gtk::FileChooserDialog * openDialog;
	Gtk::FileChooserDialog * saveDialog;
	Gtk::Dialog * proceedDialog;

	sigc::connection con1, con2;

};

}

#endif
